@@ -76,7 +76,7 @@ class KDEVPLATFORMDOCUMENTATION_EXPORT ProvidersModel : public QAbstractListMode
 {
     Q_OBJECT
 public:
-    explicit ProvidersModel(QObject* parent = 0);
+    explicit ProvidersModel(QObject* parent = nullptr);
 
     QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
     int rowCount(const QModelIndex& idx = QModelIndex()) const override;
