@@ -130,18 +130,14 @@ public:
         QObject::connect(&m_timer, &QTimer::timeout, m_parser, &BackgroundParser::parseDocuments);
     }
 
-    void startTimerThreadSafe() {
-        QMetaObject::invokeMethod(m_parser, "startTimer", Qt::QueuedConnection);
+    void startTimerThreadSafe(int delay) {
+        QMetaObject::invokeMethod(m_parser, "startTimer", Qt::QueuedConnection, Q_ARG(int, delay));
     }
 
     ~BackgroundParserPrivate()
     {
-        // Release dequeued jobs
-        QHashIterator<IndexedString, ThreadWeaver::QObjectDecorator*> it = m_parseJobs;
-        while (it.hasNext()) {
-            it.next();
-            delete it.value();
-        }
+        m_weaver.resume();
+        m_weaver.finish();
     }
 
     // Non-mutex guarded functions, only call with m_mutex acquired.
@@ -323,7 +319,12 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
         m_delay = BACKWARDS_COMPATIBLE_ENTRY("Delay", 500);
         m_timer.setInterval(m_delay);
         m_threads = 0;
-        m_parser->setThreadCount(BACKWARDS_COMPATIBLE_ENTRY("Number of Threads", QThread::idealThreadCount()));
+
+        if (qEnvironmentVariableIsSet("KDEV_BACKGROUNDPARSER_MAXTHREADS")) {
+            m_parser->setThreadCount(qgetenv("KDEV_BACKGROUNDPARSER_MAXTHREADS").toInt());
+        } else {
+            m_parser->setThreadCount(BACKWARDS_COMPATIBLE_ENTRY("Number of Threads", QThread::idealThreadCount()));
+        }
 
         resume();
 
@@ -336,10 +337,13 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
 
     void suspend()
     {
+        qCDebug(LANGUAGE) << "Suspending background parser";
+
         bool s = m_weaver.state()->stateId() == ThreadWeaver::Suspended ||
                  m_weaver.state()->stateId() == ThreadWeaver::Suspending;
 
         if (s) { // Already suspending
+            qCWarning(LANGUAGE) << "Already suspended or suspending";
             return;
         }
 
@@ -430,8 +434,6 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
     QMap<int, QSet<IndexedString> > m_documentsForPriority;
     // Currently running parse jobs
     QHash<IndexedString, ThreadWeaver::QObjectDecorator*> m_parseJobs;
-    // A change tracker for each managed document
-    QHash<IndexedString, DocumentChangeTracker*> m_managed;
     // The url for each managed document. Those may temporarily differ from the real url.
     QHash<KTextEditor::Document*, IndexedString> m_managedTextDocumentUrls;
     // Projects currently in progress of loading
@@ -439,8 +441,14 @@ config.readEntry(entry, oldConfig.readEntry(entry, default))
 
     ThreadWeaver::Queue m_weaver;
 
+    // generic high-level mutex
     QMutex m_mutex;
 
+    // local mutex only protecting m_managed
+    QMutex m_managedMutex;
+    // A change tracker for each managed document
+    QHash<IndexedString, DocumentChangeTracker*> m_managed;
+
     int m_maxParseJobs;
     int m_doneParseJobs;
     QHash<KDevelop::ParseJob*, float> m_jobProgress;
@@ -528,7 +536,8 @@ void BackgroundParser::revertAllRequests(QObject* notifyWhenReady)
     }
 }
 
-void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Features features, int priority, QObject* notifyWhenReady, ParseJob::SequentialProcessingFlags flags)
+void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Features features, int priority,
+                                   QObject* notifyWhenReady, ParseJob::SequentialProcessingFlags flags, int delay)
 {
 //     qCDebug(LANGUAGE) << "BackgroundParser::addDocument" << url.toUrl();
     Q_ASSERT(isValidURL(url));
@@ -555,7 +564,10 @@ void BackgroundParser::addDocument(const IndexedString& url, TopDUContext::Featu
             ++d->m_maxParseJobs; //So the progress-bar waits for this document
         }
 
-        d->startTimerThreadSafe();
+        if ( delay == ILanguageSupport::DefaultDelay ) {
+            delay = d->m_delay;
+        }
+        d->startTimerThreadSafe(delay);
     }
 }
 
@@ -588,7 +600,7 @@ void BackgroundParser::removeDocument(const IndexedString& url, QObject* notifyW
 void BackgroundParser::parseDocuments()
 {
     if (!d->m_loadingProjects.empty()) {
-        startTimer();
+        startTimer(d->m_delay);
         return;
     }
     QMutexLocker lock(&d->m_mutex);
@@ -659,7 +671,14 @@ void BackgroundParser::setNeededPriority(int priority)
 {
     QMutexLocker lock(&d->m_mutex);
     d->m_neededPriority = priority;
-    d->startTimerThreadSafe();
+    d->startTimerThreadSafe(d->m_delay);
+}
+
+void BackgroundParser::abortAllJobs()
+{
+    qCDebug(LANGUAGE) << "Aborting all parse jobs";
+
+    d->m_weaver.requestAbort();
 }
 
 void BackgroundParser::suspend()
@@ -672,7 +691,6 @@ void BackgroundParser::suspend()
 void BackgroundParser::resume()
 {
     d->resume();
-
     updateProgressBar();
 }
 
@@ -725,8 +743,7 @@ void BackgroundParser::setDelay(int miliseconds)
 
 QList< IndexedString > BackgroundParser::managedDocuments()
 {
-    QMutexLocker l(&d->m_mutex);
-
+    QMutexLocker l(&d->m_managedMutex);
     return d->m_managed.keys();
 }
 
@@ -737,9 +754,12 @@ DocumentChangeTracker* BackgroundParser::trackerForUrl(const KDevelop::IndexedSt
         // yet associated with a top ctx.
         return 0;
     }
+    if ( !isValidURL(url) ) {
+        qWarning() << "Tracker requested for invalild URL:" << url.toUrl();
+    }
     Q_ASSERT(isValidURL(url));
 
-    QMutexLocker l(&d->m_mutex);
+    QMutexLocker l(&d->m_managedMutex);
     return d->m_managed.value(url, 0);
 }
 
@@ -757,6 +777,8 @@ void BackgroundParser::documentClosed(IDocument* document)
         Q_ASSERT(d->m_managedTextDocumentUrls.contains(textDocument));
 
         IndexedString url(d->m_managedTextDocumentUrls[textDocument]);
+        
+        QMutexLocker l2(&d->m_managedMutex);
         Q_ASSERT(d->m_managed.contains(url));
 
         qCDebug(LANGUAGE) << "removing" << url.str() << "from background parser";
@@ -776,6 +798,7 @@ void BackgroundParser::documentLoaded( IDocument* document )
         IndexedString url(document->url());
         // Some debugging because we had issues with this
 
+        QMutexLocker l2(&d->m_managedMutex);
         if(d->m_managed.contains(url) && d->m_managed[url]->document() == textDocument)
         {
             qCDebug(LANGUAGE) << "Got redundant documentLoaded from" << document->url() << textDocument;
@@ -800,12 +823,12 @@ void BackgroundParser::documentUrlChanged(IDocument* document)
     documentClosed(document);
 
     // Only call documentLoaded if the file wasn't renamed to a filename that is already tracked.
-    if(document->textDocument() && !d->m_managed.contains(IndexedString(document->textDocument()->url())))
+    if(document->textDocument() && !trackerForUrl(IndexedString(document->textDocument()->url())))
         documentLoaded(document);
 }
 
-void BackgroundParser::startTimer() {
-    d->m_timer.start(d->m_delay);
+void BackgroundParser::startTimer(int delay) {
+    d->m_timer.start(delay);
 }
 
 void BackgroundParser::projectAboutToBeOpened(IProject* project)
