@@ -21,7 +21,9 @@
 #ifndef KDEVPLATFORM_URLPARSELOCK_H
 #define KDEVPLATFORM_URLPARSELOCK_H
 
-#include "../duchain/indexedstring.h"
+#include <language/languageexport.h>
+
+#include <serialization/indexedstring.h>
 
 namespace KDevelop
 {
@@ -34,10 +36,13 @@ namespace KDevelop
  *
  * @warning No other mutex must be locked when this lock is acquired, to prevent deadlocks
  */
-class KDEVPLATFORMLANGUAGE_EXPORT UrlParseLock {
+class KDEVPLATFORMLANGUAGE_EXPORT UrlParseLock
+{
 public:
-  UrlParseLock(IndexedString url);
+  explicit UrlParseLock(const IndexedString& url);
   ~UrlParseLock();
+
+private:
   IndexedString m_url;
 };
 
