@@ -41,6 +41,7 @@
 #include "../backgroundparser/backgroundparser.h"
 #include "util/debug.h"
 
+#include "language-features.h"
 #include "topducontext.h"
 #include "topducontextdata.h"
 #include "topducontextdynamicdata.h"
@@ -57,7 +58,7 @@
 #include "waitforupdate.h"
 #include "importers.h"
 
-#ifdef HAVE_MALLOC_TRIM
+#if HAVE_MALLOC_TRIM
 #include "malloc.h"
 #endif
 
@@ -286,7 +287,7 @@ class DUChainPrivate
           //Just to make sure the cache is cleared periodically
           ModificationRevisionSet::clearCache();
 
-          m_data->doMoreCleanup(SOFT_CLEANUP_STEPS);
+          m_data->doMoreCleanup(SOFT_CLEANUP_STEPS, TryLock);
           if(m_stopRunning)
             break;
         }
@@ -366,7 +367,7 @@ public:
 
     QMutexLocker l(&m_chainsMutex);
 
-    foreach(TopDUContext* top, m_chainsByUrl.values())
+    foreach(TopDUContext* top, m_chainsByUrl)
       removeDocumentChainFromMemory(top);
 
     m_indexEnvironmentInformations.clear();
@@ -680,11 +681,20 @@ public:
     return m_cleanupMutex;
   }
 
+  /// defines how we interact with the ongoing language parse jobs
+  enum LockFlag {
+    /// no locking required, only used when we locked previously
+    NoLock = 0,
+    /// lock all parse jobs and block until we succeeded. required at shutdown
+    BlockingLock = 1,
+    /// only try to lock and abort on failure, good for the intermittent cleanups
+    TryLock = 2,
+  };
   ///@param retries When this is nonzero, then doMoreCleanup will do the specified amount of cycles
   ///doing the cleanup without permanently locking the du-chain. During these steps the consistency
   ///of the disk-storage is not guaranteed, but only few changes will be done during these steps,
   ///so the final step where the duchain is permanently locked is much faster.
-  void doMoreCleanup(int retries = 0, bool needLockRepository = true) {
+  void doMoreCleanup(int retries = 0, LockFlag lockFlag = BlockingLock) {
 
     if(m_cleanupDisabled)
       return;
@@ -697,25 +707,33 @@ public:
 
     Q_ASSERT(!instance->lock()->currentThreadHasReadLock() && !instance->lock()->currentThreadHasWriteLock());
     DUChainWriteLocker writeLock(instance->lock());
-    PersistentSymbolTable::self().clearCache();
 
     //This is used to stop all parsing before starting to do the cleanup. This way less happens during the
     //soft cleanups, and we have a good chance that during the "hard" cleanup only few data has to be written.
-    QList<ILanguageSupport*> lockedParseMutexes;
-
     QList<QReadWriteLock*> locked;
 
-    if(needLockRepository) {
-
+    if (lockFlag != NoLock) {
+      QList<ILanguageSupport*> languages;
       if (ICore* core = ICore::self())
         if (ILanguageController* lc = core->languageController())
-          lockedParseMutexes = lc->loadedLanguages();
+          languages = lc->loadedLanguages();
 
       writeLock.unlock();
 
       //Here we wait for all parsing-threads to stop their processing
-      foreach(const auto language, lockedParseMutexes) {
-        language->parseLock()->lockForWrite();
+      foreach(const auto language, languages) {
+        if (lockFlag == TryLock) {
+          if (!language->parseLock()->tryLockForWrite()) {
+            qCDebug(LANGUAGE) << "Aborting cleanup because language plugin is still parsing:" << language->name();
+            // some language is still parsing, don't interfere with the cleanup
+            foreach(auto* lock, locked) {
+              lock->unlock();
+            }
+            return;
+          }
+        } else {
+          language->parseLock()->lockForWrite();
+        }
         locked << language->parseLock();
       }
 
@@ -726,6 +744,7 @@ public:
     }
 
     QTime startTime = QTime::currentTime();
+    PersistentSymbolTable::self().clearCache();
 
     storeAllInformation(!retries, writeLock); //Puts environment-information into a repository
 
@@ -735,7 +754,8 @@ public:
     {
       QMutexLocker l(&m_chainsMutex);
 
-      foreach(TopDUContext* top, m_chainsByUrl.values()) {
+      workOnContexts.reserve(m_chainsByUrl.size());
+      foreach(TopDUContext* top, m_chainsByUrl) {
         workOnContexts << top;
         Q_ASSERT(hasChainForIndex(top->ownIndex()));
       }
@@ -874,11 +894,11 @@ public:
 
 
       if(retries) {
-        doMoreCleanup(retries-1, false);
+        doMoreCleanup(retries-1, NoLock);
         writeLock.lock();
       }
 
-      if(needLockRepository) {
+      if(lockFlag != NoLock) {
         globalItemRepositoryRegistry().unlockForWriting();
 
         int elapsedSeconds = startTime.secsTo(QTime::currentTime());
@@ -892,12 +912,12 @@ public:
       foreach(QReadWriteLock* lock, locked)
         lock->unlock();
 
-    #ifdef HAVE_MALLOC_TRIM
+#if HAVE_MALLOC_TRIM
     // trim unused memory but keep a pad buffer of about 50 MB
     // this can greatly decrease the perceived memory consumption of kdevelop
     // see: https://sourceware.org/bugzilla/show_bug.cgi?id=14827
     malloc_trim(50 * 1024 * 1024);
-    #endif
+#endif
   }
 
   ///Checks whether the information is already loaded.
@@ -1413,7 +1433,8 @@ QList<QUrl> DUChain::documents() const
   QMutexLocker l(&sdDUChainPrivate->m_chainsMutex);
 
   QList<QUrl> ret;
-  foreach(TopDUContext* top, sdDUChainPrivate->m_chainsByUrl.values()) {
+  ret.reserve(sdDUChainPrivate->m_chainsByUrl.count());
+  foreach(TopDUContext* top, sdDUChainPrivate->m_chainsByUrl) {
     ret << top->url().toUrl();
   }
 
@@ -1425,7 +1446,8 @@ QList<IndexedString> DUChain::indexedDocuments() const
   QMutexLocker l(&sdDUChainPrivate->m_chainsMutex);
 
   QList<IndexedString> ret;
-  foreach(TopDUContext* top, sdDUChainPrivate->m_chainsByUrl.values()) {
+  ret.reserve(sdDUChainPrivate->m_chainsByUrl.count());
+  foreach(TopDUContext* top, sdDUChainPrivate->m_chainsByUrl) {
     ret << top->url();
   }
 
@@ -1436,14 +1458,28 @@ void DUChain::documentActivated(KDevelop::IDocument* doc)
 {
   if(sdDUChainPrivate->m_destroyed)
     return;
-  //Check whether the document has an attached environment-manager, and whether that one thinks the document needs to be updated.
-  //If yes, update it.
+
   DUChainReadLocker lock( DUChain::lock() );
   QMutexLocker l(&sdDUChainPrivate->m_chainsMutex);
+
+  auto backgroundParser = ICore::self()->languageController()->backgroundParser();
+  auto addWithHighPriority = [backgroundParser, doc]() {
+    backgroundParser->addDocument(IndexedString(doc->url()),
+                                  TopDUContext::VisibleDeclarationsAndContexts,
+                                  BackgroundParser::BestPriority);
+  };
+
   TopDUContext* ctx = DUChainUtils::standardContextForUrl(doc->url(), true);
-  if(ctx && ctx->parsingEnvironmentFile())
-    if(ctx->parsingEnvironmentFile()->needsUpdate())
-      ICore::self()->languageController()->backgroundParser()->addDocument(IndexedString(doc->url()));
+  //Check whether the document has an attached environment-manager, and whether that one thinks the document needs to be updated.
+  //If yes, update it.
+  if (ctx && ctx->parsingEnvironmentFile() && ctx->parsingEnvironmentFile()->needsUpdate()) {
+    qCDebug(LANGUAGE) << "Document needs update, using best priority since it just got activated:" << doc->url();
+    addWithHighPriority();
+  } else if (backgroundParser->managedDocuments().contains(IndexedString(doc->url()))) {
+    // increase priority if there's already parse job of this document in the queue
+    qCDebug(LANGUAGE) << "Prioritizing activated document:" << doc->url();
+    addWithHighPriority();
+  }
 }
 
 void DUChain::documentClosed(IDocument* document)
@@ -1634,9 +1670,20 @@ void DUChain::refCountDown(TopDUContext* top) {
 
 void DUChain::emitDeclarationSelected(const DeclarationPointer& decl)
 {
+  if(sdDUChainPrivate->m_destroyed)
+    return;
+
   emit declarationSelected(decl);
 }
 
+void DUChain::emitUpdateReady(const IndexedString& url, const ReferencedTopDUContext& topContext)
+{
+  if(sdDUChainPrivate->m_destroyed)
+    return;
+
+  emit updateReady(url, topContext);
+}
+
 KDevelop::ReferencedTopDUContext DUChain::waitForUpdate(const KDevelop::IndexedString& document, KDevelop::TopDUContext::Features minFeatures, bool proxyContext) {
   Q_ASSERT(!lock()->currentThreadHasReadLock() && !lock()->currentThreadHasWriteLock());
 
