@@ -59,13 +59,16 @@ class KDEVPLATFORMLANGUAGE_EXPORT AbstractNavigationContext : public QObject, pu
 {
   Q_OBJECT
   public:
-    explicit AbstractNavigationContext( KDevelop::TopDUContextPointer topContext = KDevelop::TopDUContextPointer(), AbstractNavigationContext* previousContext = 0 );
+    explicit AbstractNavigationContext( KDevelop::TopDUContextPointer topContext = KDevelop::TopDUContextPointer(), AbstractNavigationContext* previousContext = nullptr );
 
-    virtual ~AbstractNavigationContext() {
+    ~AbstractNavigationContext() override {
     }
 
     void nextLink();
     void previousLink();
+
+    int linkCount() const;
+
     void up();
     void down();
     void setPrefixSuffix( const QString& prefix, const QString& suffix );
