@@ -127,7 +127,7 @@ void AbstractNavigationWidget::updateIdealSize() const {
     QTextDocument doc;
     doc.setHtml(m_currentText);
     if(doc.idealWidth() > maxNavigationWidgetWidth) {
-      doc.setPageSize( QSize(maxNavigationWidgetWidth, 30) );
+      doc.setTextWidth(maxNavigationWidgetWidth);
       m_idealTextSize.setWidth(maxNavigationWidgetWidth);
     }else{
       m_idealTextSize.setWidth(doc.idealWidth());
@@ -136,6 +136,10 @@ void AbstractNavigationWidget::updateIdealSize() const {
   }
 }
 
+void AbstractNavigationWidget::setDisplayHints(DisplayHints hints) {
+  m_hints = hints;
+}
+
 void AbstractNavigationWidget::update() {
   setUpdatesEnabled(false);
   Q_ASSERT( m_context );
@@ -144,9 +148,21 @@ void AbstractNavigationWidget::update() {
   if(!html.isEmpty()) {
     int scrollPos = m_browser->verticalScrollBar()->value();
 
+    if ( !(m_hints & EmbeddableWidget)) {
+      // TODO: Only show that the first time, or the first few times this context is shown?
+      html += QStringLiteral("<p><small>");
+      if (m_context->linkCount() > 0) {
+        html += i18n("(Hold 'Alt' to show. Navigate via arrow keys, activate by pressing 'Enter')");
+      } else {
+        html += i18n("(Hold 'Alt' to show this tooltip)");
+      }
+      html += QStringLiteral("</small></p>");
+    }
+
     m_browser->setHtml( html );
 
     m_currentText = html;
+
     m_idealTextSize = QSize();
 
     QSize hint = sizeHint();
@@ -201,8 +217,6 @@ void AbstractNavigationWidget::navigateDeclaration(KDevelop::IndexedDeclaration
 }
 
 void AbstractNavigationWidget::anchorClicked(const QUrl& url) {
-  DUChainReadLocker lock( DUChain::lock() );
-
   //We may get deleted while the call to acceptLink, so make sure we don't crash in that case
   QPointer<AbstractNavigationWidget> thisPtr(this);
   NavigationContextPointer oldContext = m_context;
