@@ -20,14 +20,12 @@
 #ifndef KDEVPLATFORM_TOPDUCONTEXT_H
 #define KDEVPLATFORM_TOPDUCONTEXT_H
 
-#include <QtCore/QMutex>
-
 #include "ducontext.h"
 #include <language/util/setrepository.h>
 #include <QMetaType>
 
 template< class T >
-class KSharedPtr;
+class QExplicitlySharedDataPointer;
 
 namespace KDevelop
 {
@@ -54,7 +52,7 @@ namespace KDevelop
   
   typedef DUChainPointer<TopDUContext> TopDUContextPointer;
 
-  typedef KSharedPtr<Problem> ProblemPointer;
+  typedef QExplicitlySharedDataPointer<Problem> ProblemPointer;
 
 ///KDevelop can unload unused top-context at any time. To prevent unloading,
 ///keep a ReferencedTopDUContext.
@@ -111,46 +109,27 @@ class KDEVPLATFORMLANGUAGE_EXPORT TopDUContext : public DUContext
 public:
   explicit TopDUContext(const IndexedString& url, const RangeInRevision& range, ParsingEnvironmentFile* file = 0);
   explicit TopDUContext(TopDUContextData& data);
-  
-  /**This creates a top-context that shares most of its data with @param sharedDataFrom. The given context must be the owner of the data
-   * (it must not have been created with this constructor).
-   * 
-   * When creating a context like this, all the data is shared among the context, except:
-   * parsingEnvironmentFile, ownIndex, problems, imports and importers.
-   * 
-   * When you change any other attributes(including duchain data etc.), that data is changed within all contexts that also share the data of the
-   * given one.
-   * 
-   * Special thing to consider: The imported contexts will be merged with the imported contexts of the data owner, and the problems will be merged
-   * with the problems of the data owner. When one of these things changes in the data owner, it will automatically also change in this context.
-   * 
-   * @warning When creating context with shared data, the shared ones always have to be deleted before the owner is deleted.
-   * */
-  explicit TopDUContext(TopDUContext* shareDataFrom, ParsingEnvironmentFile* file = 0);
 
-  ///If this top-context uses the data from another top-context, this returns that one.
-  TopDUContext* sharedDataOwner() const;
-  
-  TopDUContext* topContext() const;
+  TopDUContext* topContext() const override;
 
   ///Returns an indexed representation of this top-context. Indexed representations stay valid even if the top-context is unloaded.
   IndexedTopDUContext indexed() const;
   
   uint ownIndex() const;
   
-  IndexedString url() const;
+  IndexedString url() const override;
   
   /**
    * @see ParsingEnvironmentFile
    * May return zero if no file was set.
    * */
-  KSharedPtr<ParsingEnvironmentFile> parsingEnvironmentFile() const;
+  QExplicitlySharedDataPointer<ParsingEnvironmentFile> parsingEnvironmentFile() const;
 
   /// Returns true if this object is being deleted, otherwise false.
   bool deleting() const;
 
   /// Returns true if this object is registered in the du-chain. If it is not, all sub-objects(context, declarations, etc.) can be changed
-  virtual bool inDUChain() const;
+  virtual bool inDUChain() const override;
   /// This flag is only used by DUChain, never change it from outside.
   void setInDuChain(bool);
 
@@ -170,13 +149,6 @@ public:
    * */
   void addProblem(const ProblemPointer& problem);
 
-  /**
-   * Remove a parsing-problem from this context.
-   *
-   * \note you must be holding a write lock when you access this function.
-   * */
-  void removeProblem(const ProblemPointer& problem);
-
   /**
    * Clear the list of problems
    *
@@ -199,21 +171,13 @@ public:
    * 
    * \note you must be holding a read but not a write chain lock when you access this function.
    */
-  virtual bool imports(const DUContext* origin, const CursorInRevision& position) const;
+  virtual bool imports(const DUContext* origin, const CursorInRevision& position) const override;
 
   enum {
     Identity = 4
   };
-  
-  enum Flags {
-    NoFlags = 0,
-    ///Can be used by language parts to mark contexts they currently update(for their internal usage)
-    UpdatingContext = 1,
-    ///You can define own language-dependent flags behind this flag
-    LastFlag = 2
-  };
-  
-  enum Features {
+
+  enum Features : quint16 {
     ///Top-context features standard that can be requested from the duchain, and that are stored in the features() member.
     Empty = 0, //Only the top-context structure (imports etc.) is built, but no declarations and no contexts
     SimplifiedVisibleDeclarationsAndContexts = 2, //The top-context should only contain publically simplified accessible declarations and contexts, without doing type look-up,
@@ -268,14 +232,8 @@ public:
   /**
    * Recursively deletes all contained uses, declaration-indices, etc.
    */
-  virtual void deleteUsesRecursively();
-  
-  /**
-   * Use flags to mark top-contexts for special behavior. Any flags above LastFlag may be used for language-specific stuff.
-   * */
-  Flags flags() const;
-  void setFlags(Flags f);
-  
+  virtual void deleteUsesRecursively() override;
+
   /**
    * Returns the AST Container, that contains the AST created during parsing.
    * This is only created if you request the AST feature for parsing.
@@ -284,12 +242,12 @@ public:
    *
    * @todo Figure out logic to get rid of AST when it is not needed/useful
    */
-  KSharedPtr<IAstContainer> ast() const;
+  QExplicitlySharedDataPointer<IAstContainer> ast() const;
   
   /**
    * Sets the AST Container.
   */
-  void setAst(KSharedPtr<IAstContainer> ast);
+  void setAst(QExplicitlySharedDataPointer<IAstContainer> ast);
   
   /**
    * Utility function to clear the AST Container
@@ -299,7 +257,7 @@ public:
   ///@param temporary If this is true, importers of this context will not be notified of the new imports. This greatly increases performance while removing the context,
   ///but creates in inconsistent import-structure. Therefore it is only suitable for temporary imports. These imports will not be visible from contexts that import this one.
   ///When this top-context does not own its private data, the import is added locally only to this context, not into the shared data.
-  virtual void addImportedParentContext(DUContext* context, const CursorInRevision& position = CursorInRevision(), bool anonymous=false, bool temporary=false);
+  virtual void addImportedParentContext(DUContext* context, const CursorInRevision& position = CursorInRevision(), bool anonymous=false, bool temporary=false) override;
   ///Use this for mass-adding of imported contexts, it is faster than adding them individually.
   ///@param temporary If this is true, importers of this context will not be notified of the new imports. This greatly increases performance while removing the context,
   ///but creates in inconsistent import-structure. Therefore it is only suitable for temporary imports. These imports will not be visible from contexts that import this one.
@@ -307,24 +265,24 @@ public:
   virtual void addImportedParentContexts(const QList<QPair<TopDUContext*, CursorInRevision> >& contexts, bool temporary=false);
 
   ///When this top-context does not own its private data, the import is removed locally only from this context, not from the shared data.
-  virtual void removeImportedParentContext(DUContext* context);
+  virtual void removeImportedParentContext(DUContext* context) override;
   ///Use this for mass-removing of imported contexts, it is faster than removing them individually.
   ///When this top-context does not own its private data, the import is removed locally only from this context, not from the shared data.
   virtual void removeImportedParentContexts(const QList<TopDUContext*>& contexts);
 
   ///When this top-context does not own its private data, only the local imports of this context are removed, not those from the shared data.
-  virtual void clearImportedParentContexts();
+  virtual void clearImportedParentContexts() override;
   
   typedef Utils::StorableSet<IndexedTopDUContext, IndexedTopDUContextIndexConversion, RecursiveImportRepository, true> IndexedRecursiveImports;
   
-  virtual QVector<Import> importedParentContexts() const;
+  virtual QVector<Import> importedParentContexts() const override;
   
-  virtual QVector<DUContext*> importers() const;
+  virtual QVector<DUContext*> importers() const override;
 
   ///Returns all currently loade importers
   virtual QList<DUContext*> loadedImporters() const;
   
-  virtual CursorInRevision importPosition(const DUContext* target) const;
+  virtual CursorInRevision importPosition(const DUContext* target) const override;
   
   ///Returns the set of all recursively imported top-contexts. If import-caching is used, this returns the cached set.
   ///The list also contains this context itself. This set is used to determine declaration-visibility from within this top-context.
@@ -347,7 +305,7 @@ public:
   
   bool usingImportsCache() const;
 
-  virtual bool findDeclarationsInternal(const SearchItem::PtrList& identifiers, const CursorInRevision& position, const AbstractType::Ptr& dataType, DeclarationList& ret, const TopDUContext* source, SearchFlags flags, uint depth) const;
+  virtual bool findDeclarationsInternal(const SearchItem::PtrList& identifiers, const CursorInRevision& position, const AbstractType::Ptr& dataType, DeclarationList& ret, const TopDUContext* source, SearchFlags flags, uint depth) const override;
 protected:
   void setParsingEnvironmentFile(ParsingEnvironmentFile*);
 
@@ -363,7 +321,7 @@ protected:
   virtual ~TopDUContext();
   
   void clearFeaturesSatisfied();
-  void rebuildDynamicData(DUContext* parent, uint ownIndex);
+  void rebuildDynamicData(DUContext* parent, uint ownIndex) override;
   //Must be called after all imported top-contexts were loaded into the du-chain
   void rebuildDynamicImportStructure();
   
@@ -389,10 +347,12 @@ protected:
   friend class TopDUContextDynamicData;
   friend class Declaration;
   friend class DUContext;
+  friend class Problem;
   friend class IndexedDeclaration;
   friend class IndexedDUContext;
   friend class LocalIndexedDeclaration;
   friend class LocalIndexedDUContext;
+  friend class LocalIndexedProblem;
   friend class DeclarationId;
   friend class ParsingEnvironmentFile;
   
@@ -410,13 +370,7 @@ inline uint qHash(const ReferencedTopDUContext& ctx) {
   return ctx.hash();
 }
 
-inline uint qHash(const IndexedTopDUContext& ctx) {
-  return ctx.index();
 }
-
-}
-Q_DECLARE_METATYPE(KDevelop::ReferencedTopDUContext);
+Q_DECLARE_METATYPE(KDevelop::ReferencedTopDUContext)
 
 #endif // KDEVPLATFORM_TOPDUCONTEXT_H
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
