@@ -27,6 +27,7 @@
 #include <QMap>
 #include <QObject>
 #include <QPointer>
+#include <QUrl>
 #include <KTextEditor/Cursor>
 
 
@@ -45,7 +46,7 @@ class EditorViewWatcher : public QObject {
     Q_OBJECT
 public:
     ///@param sameWindow If this is true, only views that are child of the same window as the given widget are registered
-    explicit EditorViewWatcher(QObject* parent = 0);
+    explicit EditorViewWatcher(QObject* parent = nullptr);
     QList<KTextEditor::View*> allViews();
 private:
     ///Called for every added view. Reimplement this to catch them.
@@ -89,15 +90,27 @@ class BrowseManager : public QObject {
         //Emitted when browsing was started using the magic-modifier
         void startDelayedBrowsing(KTextEditor::View* view);
         void stopDelayedBrowsing();
+        void invokeAction(int index);
     public slots:
         ///Enabled/disables the browsing mode
         void setBrowsing(bool);
     private slots:
         void eventuallyStartDelayedBrowsing();
     private:
+        struct JumpLocation
+        {
+            QUrl url;
+            KTextEditor::Cursor cursor;
+            JumpLocation(const QPair<QUrl, KTextEditor::Cursor>& pair = {})
+                : url(pair.first)
+                , cursor(pair.second)
+            {}
+            bool isValid() const { return url.isValid() && cursor.isValid(); }
+        };
         void resetChangedCursor();
+        JumpLocation determineJumpLoc(KTextEditor::Cursor textCursor, const QUrl& viewUrl) const;
         void setHandCursor(QWidget* widget);
-
+        void avoidMenuAltFocus();
         bool eventFilter(QObject * watched, QEvent * event) override ;
         ContextBrowserPlugin* m_plugin;
         bool m_browsing;
@@ -106,7 +119,7 @@ class BrowseManager : public QObject {
         //Maps widgets to their previously set cursors
         QMap<QPointer<QWidget>, QCursor> m_oldCursors;
         QTimer* m_delayedBrowsingTimer;
-        QPointer<KTextEditor::View> m_browingStartedInView;
+        QPointer<KTextEditor::View> m_browsingStartedInView;
         KTextEditor::Cursor m_buttonPressPosition;
 };
 
