@@ -67,9 +67,7 @@
 #include <language/duchain/aliasdeclaration.h>
 #include <language/duchain/types/functiontype.h>
 #include <language/duchain/navigation/abstractnavigationwidget.h>
-
-#include <language/backgroundparser/backgroundparser.h>
-#include <language/backgroundparser/parsejob.h>
+#include <language/duchain/navigation/problemnavigationcontext.h>
 
 #include <language/util/navigationtooltip.h>
 
@@ -125,7 +123,7 @@ DeclarationPointer cursorDeclaration()
 
   DUChainReadLocker lock;
 
-  Declaration *decl = DUChainUtils::declarationForDefinition(DUChainUtils::itemUnderCursor(view->document()->url(), KTextEditor::Cursor(view->cursorPosition())));
+  Declaration *decl = DUChainUtils::declarationForDefinition(DUChainUtils::itemUnderCursor(view->document()->url(), KTextEditor::Cursor(view->cursorPosition())).declaration);
   return DeclarationPointer(decl);
 }
 
@@ -158,10 +156,10 @@ private:
 
 KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow* window )
 {
-    KXMLGUIClient* ret = KDevelop::IPlugin::createGUIForMainWindow( window );
-
     m_browseManager = new BrowseManager(this);
 
+    KXMLGUIClient* ret = KDevelop::IPlugin::createGUIForMainWindow(window);
+
     connect(ICore::self()->documentController(), &IDocumentController::documentJumpPerformed, this, &ContextBrowserPlugin::documentJumpPerformed);
 
     m_previousButton = new QToolButton();
@@ -186,15 +184,6 @@ KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow
     connect(m_nextButton.data(), &QToolButton::clicked, this, &ContextBrowserPlugin::historyNext);
     connect(m_nextMenu.data(), &QMenu::aboutToShow, this, &ContextBrowserPlugin::nextMenuAboutToShow);
 
-    m_browseButton = new QToolButton();
-    m_browseButton->setIcon(QIcon::fromTheme(QStringLiteral("games-hint")));
-    m_browseButton->setToolTip(i18n("Enable/disable source browse mode"));
-    m_browseButton->setWhatsThis(i18n("When this is enabled, you can browse the source-code by clicking in the editor."));
-    m_browseButton->setCheckable(true);
-    m_browseButton->setFocusPolicy(Qt::NoFocus);
-
-    connect(m_browseButton.data(), &QToolButton::clicked, m_browseManager, &BrowseManager::setBrowsing);
-
     IQuickOpen* quickOpen = KDevelop::ICore::self()->pluginController()->extensionForPlugin<IQuickOpen>(QStringLiteral("org.kdevelop.IQuickOpen"));
 
     if(quickOpen) {
@@ -207,13 +196,14 @@ KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow
             this, &ContextBrowserPlugin::startDelayedBrowsing);
     connect(m_browseManager, &BrowseManager::stopDelayedBrowsing,
             this, &ContextBrowserPlugin::stopDelayedBrowsing);
+    connect(m_browseManager, &BrowseManager::invokeAction,
+            this, &ContextBrowserPlugin::invokeAction);
 
     m_toolbarWidget = toolbarWidgetForMainWindow(window);
     m_toolbarWidgetLayout = new QHBoxLayout;
     m_toolbarWidgetLayout->setSizeConstraint(QLayout::SetMaximumSize);
     m_previousButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     m_nextButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
-    m_browseButton->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     m_toolbarWidgetLayout->setMargin(0);
 
     m_toolbarWidgetLayout->addWidget(m_previousButton);
@@ -223,7 +213,6 @@ KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow
       connect(ICore::self()->documentController(), &IDocumentController::documentClosed, m_outlineLine.data(), &IQuickOpenLine::clear);
     }
     m_toolbarWidgetLayout->addWidget(m_nextButton);
-    m_toolbarWidgetLayout->addWidget(m_browseButton);
 
     if(m_toolbarWidget->children().isEmpty())
         m_toolbarWidget->setLayout(m_toolbarWidgetLayout);
@@ -237,7 +226,13 @@ KXMLGUIClient* ContextBrowserPlugin::createGUIForMainWindow( Sublime::MainWindow
 void ContextBrowserPlugin::createActionsForMainWindow(Sublime::MainWindow* window, QString& xmlFile,
                                                       KActionCollection& actions)
 {
-    xmlFile = QStringLiteral("kdevcontextbrowser.rc") ;
+    xmlFile = QStringLiteral("kdevcontextbrowser.rc");
+
+    QAction* sourceBrowseMode = actions.addAction(QStringLiteral("source_browse_mode"));
+    sourceBrowseMode->setText( i18n("Source &Browse Mode") );
+    sourceBrowseMode->setIcon( QIcon::fromTheme(QStringLiteral("arrow-up")) );
+    sourceBrowseMode->setCheckable(true);
+    connect(sourceBrowseMode, &QAction::triggered, m_browseManager, &BrowseManager::setBrowsing);
 
     QAction* previousContext = actions.addAction(QStringLiteral("previous_context"));
     previousContext->setText( i18n("&Previous Visited Context") );
@@ -291,13 +286,14 @@ ContextBrowserPlugin::ContextBrowserPlugin(QObject *parent, const QVariantList&)
     : KDevelop::IPlugin(QStringLiteral("kdevcontextbrowser"), parent)
     , m_viewFactory(new ContextBrowserViewFactory(this))
     , m_nextHistoryIndex(0)
+    , m_textHintProvider(this)
 {
   KDEV_USE_EXTENSION_INTERFACE( IContextBrowser )
 
   core()->uiController()->addToolView(i18n("Code Browser"), m_viewFactory);
 
   connect( core()->documentController(), &IDocumentController::textDocumentCreated, this, &ContextBrowserPlugin::textDocumentCreated );
-  connect( core()->languageController()->backgroundParser(), &BackgroundParser::parseJobFinished, this, &ContextBrowserPlugin::parseJobFinished);
+  connect( DUChain::self(), &DUChain::updateReady, this, &ContextBrowserPlugin::updateReady);
 
   connect( DUChain::self(), &DUChain::declarationSelected,
            this, &ContextBrowserPlugin::declarationSelectedInUI );
@@ -321,7 +317,6 @@ ContextBrowserPlugin::~ContextBrowserPlugin()
   delete m_previousButton;
   delete m_outlineLine;
   delete m_nextButton;
-  delete m_browseButton;
 }
 
 void ContextBrowserPlugin::unload()
@@ -413,6 +408,20 @@ void ContextBrowserPlugin::stopDelayedBrowsing() {
   hideToolTip();
 }
 
+void ContextBrowserPlugin::invokeAction(int index)
+{
+  if (!m_currentNavigationWidget)
+    return;
+
+
+  auto navigationWidget = qobject_cast<AbstractNavigationWidget*>(m_currentNavigationWidget);
+  if (!navigationWidget)
+    return;
+
+  // TODO: Add API in AbstractNavigation{Widget,Context}?
+  QMetaObject::invokeMethod(navigationWidget->context().data(), "executeAction", Q_ARG(int, index));
+}
+
 void ContextBrowserPlugin::startDelayedBrowsing(KTextEditor::View* view) {
   if(!m_currentToolTip) {
     showToolTip(view, view->cursorPosition());
@@ -424,45 +433,143 @@ void ContextBrowserPlugin::hideToolTip() {
     m_currentToolTip->deleteLater();
     m_currentToolTip = 0;
     m_currentNavigationWidget = 0;
+    m_currentToolTipProblem = {};
+    m_currentToolTipDeclaration = {};
   }
 }
 
+static ProblemPointer findProblemUnderCursor(TopDUContext* topContext, KTextEditor::Cursor position)
+{
+  const auto top = ReferencedTopDUContext(topContext);
+  foreach (auto problem, DUChainUtils::allProblemsForContext(top)) {
+    if (problem->rangeInCurrentRevision().contains(position)) {
+      return problem;
+    }
+  }
+
+  return {};
+}
+
+static ProblemPointer findProblemCloseToCursor(TopDUContext* topContext, KTextEditor::Cursor position, KTextEditor::View* view)
+{
+  const auto top = ReferencedTopDUContext(topContext);
+  auto problems = DUChainUtils::allProblemsForContext(top);
+  if (problems.isEmpty())
+    return {};
+
+  auto closestProblem = std::min_element(problems.constBegin(), problems.constEnd(),
+                                         [position](const ProblemPointer& a, const ProblemPointer& b) {
+    const auto aRange = a->rangeInCurrentRevision();
+    const auto bRange = b->rangeInCurrentRevision();
+
+    const auto aLineDistance = qMin(qAbs(aRange.start().line() - position.line()),
+                                    qAbs(aRange.end().line() - position.line()));
+    const auto bLineDistance = qMin(qAbs(bRange.start().line() - position.line()),
+                                    qAbs(bRange.end().line() - position.line()));
+    if (aLineDistance != bLineDistance) {
+      return aLineDistance < bLineDistance;
+    }
+
+    if (aRange.start().line() == bRange.start().line()) {
+      return qAbs(aRange.start().column() - position.column()) <
+        qAbs(bRange.start().column() - position.column());
+    }
+    return qAbs(aRange.end().column() - position.column()) <
+      qAbs(bRange.end().column() - position.column());
+  });
+
+  auto r = (*closestProblem)->rangeInCurrentRevision();
+  if (!r.contains(position)) {
+    if (r.start().line() == position.line() || r.end().line() == position.line()) {
+      // problem is on the same line, let's use it
+      return *closestProblem;
+    }
+
+    // if not, only show it in case there's only whitespace between the current cursor pos and the problem
+    auto dist = position < r.start() ? KTextEditor::Range(position, r.start()) : KTextEditor::Range(r.end(), position);
+    auto textBetween = view->document()->text(dist);
+    auto isSpace = std::all_of(textBetween.begin(), textBetween.end(), [](QChar c) { return c.isSpace(); });
+    if (!isSpace) {
+      return {};
+    }
+  }
+
+  return *closestProblem;
+}
+
+QWidget* ContextBrowserPlugin::navigationWidgetForPosition(KTextEditor::View* view, KTextEditor::Cursor position)
+{
+  QUrl viewUrl = view->document()->url();
+  auto languages = ICore::self()->languageController()->languagesForUrl(viewUrl);
+
+  DUChainReadLocker lock(DUChain::lock());
+  foreach (const auto language, languages) {
+    auto widget = language->specialLanguageObjectNavigationWidget(viewUrl, KTextEditor::Cursor(position));
+    auto navigationWidget = qobject_cast<AbstractNavigationWidget*>(widget);
+    if(navigationWidget)
+      return navigationWidget;
+  }
+
+  TopDUContext* topContext = DUChainUtils::standardContextForUrl(view->document()->url());
+  if (topContext) {
+    // first pass: find problems under the cursor
+    const auto problem = findProblemUnderCursor(topContext, position);
+    if (problem) {
+      if (problem == m_currentToolTipProblem && m_currentToolTip) {
+        return nullptr;
+      }
+
+      m_currentToolTipProblem = problem;
+      auto widget = new AbstractNavigationWidget;
+      auto context = new ProblemNavigationContext(problem);
+      context->setTopContext(TopDUContextPointer(topContext));
+      widget->setContext(NavigationContextPointer(context));
+      return widget;
+    }
+  }
+
+  auto declUnderCursor = DUChainUtils::itemUnderCursor(viewUrl, position).declaration;
+  Declaration* decl = DUChainUtils::declarationForDefinition(declUnderCursor);
+  if (decl && decl->kind() == Declaration::Alias) {
+    AliasDeclaration* alias = dynamic_cast<AliasDeclaration*>(decl);
+    Q_ASSERT(alias);
+    DUChainReadLocker lock;
+    decl = alias->aliasedDeclaration().declaration();
+  }
+  if(decl) {
+    if(m_currentToolTipDeclaration == IndexedDeclaration(decl) && m_currentToolTip)
+      return nullptr;
+
+    m_currentToolTipDeclaration = IndexedDeclaration(decl);
+    return decl->context()->createNavigationWidget(decl, DUChainUtils::standardContextForUrl(viewUrl));
+  }
+
+  if (topContext) {
+    // second pass: find closest problem to the cursor
+    const auto problem = findProblemCloseToCursor(topContext, position, view);
+    if (problem) {
+      if (problem == m_currentToolTipProblem && m_currentToolTip) {
+        return nullptr;
+      }
+
+      m_currentToolTipProblem = problem;
+      auto widget = new AbstractNavigationWidget;
+      // since the problem is not under cursor: show location
+      widget->setContext(NavigationContextPointer(new ProblemNavigationContext(problem, ProblemNavigationContext::ShowLocation)));
+      return widget;
+    }
+  }
+
+  return nullptr;
+}
+
 void ContextBrowserPlugin::showToolTip(KTextEditor::View* view, KTextEditor::Cursor position) {
 
   ContextBrowserView* contextView = browserViewForWidget(view);
   if(contextView && contextView->isVisible() && !contextView->isLocked())
     return; // If the context-browser view is visible, it will care about updating by itself
 
-  QUrl viewUrl = view->document()->url();
-  auto languages = ICore::self()->languageController()->languagesForUrl(viewUrl);
-
-  QWidget* navigationWidget = 0;
-  {
-    DUChainReadLocker lock(DUChain::lock());
-    foreach (const auto language, languages) {
-      auto widget = language->specialLanguageObjectNavigationWidget(viewUrl, KTextEditor::Cursor(position));
-      navigationWidget = qobject_cast<AbstractNavigationWidget*>(widget);
-      if(navigationWidget)
-        break;
-    }
-
-    if(!navigationWidget) {
-      Declaration* decl = DUChainUtils::declarationForDefinition( DUChainUtils::itemUnderCursor(viewUrl, KTextEditor::Cursor(position)) );
-      if (decl && decl->kind() == Declaration::Alias) {
-        AliasDeclaration* alias = dynamic_cast<AliasDeclaration*>(decl);
-        Q_ASSERT(alias);
-        DUChainReadLocker lock;
-        decl = alias->aliasedDeclaration().declaration();
-      }
-      if(decl) {
-        if(m_currentToolTipDeclaration == IndexedDeclaration(decl) && m_currentToolTip)
-          return;
-        m_currentToolTipDeclaration = IndexedDeclaration(decl);
-        navigationWidget = decl->context()->createNavigationWidget(decl, DUChainUtils::standardContextForUrl(viewUrl));
-      }
-    }
-  }
-
+  auto navigationWidget = navigationWidgetForPosition(view, position);
   if(navigationWidget) {
 
     // If we have an invisible context-view, assign the tooltip navigation-widget to it.
@@ -480,10 +587,15 @@ void ContextBrowserPlugin::showToolTip(KTextEditor::View* view, KTextEditor::Cur
     KTextEditor::Range itemRange;
     {
       DUChainReadLocker lock;
-      itemRange = DUChainUtils::itemRangeUnderCursor(viewUrl, KTextEditor::Cursor(position));
+      auto viewUrl = view->document()->url();
+      itemRange = DUChainUtils::itemUnderCursor(viewUrl, position).range;
     }
-    tooltip->setHandleRect(getItemBoundingRect(view, itemRange));
+    tooltip->setHandleRect(KTextEditorHelpers::getItemBoundingRect(view, itemRange));
     tooltip->resize( navigationWidget->sizeHint() + QSize(10, 10) );
+    QObject::connect( view, &KTextEditor::View::verticalScrollPositionChanged,
+                      this, &ContextBrowserPlugin::hideToolTip );
+    QObject::connect( view, &KTextEditor::View::horizontalScrollPositionChanged,
+                      this, &ContextBrowserPlugin::hideToolTip );
     qCDebug(PLUGIN_CONTEXTBROWSER) << "tooltip size" << tooltip->size();
     m_currentToolTip = tooltip;
     m_currentNavigationWidget = navigationWidget;
@@ -581,7 +693,7 @@ Declaration* ContextBrowserPlugin::findDeclaration(View* view, const KTextEditor
         foundDeclaration = m_useDeclaration.data();
       }else{
         //If we haven't found a special language object, search for a use/declaration and eventually highlight it
-        foundDeclaration = DUChainUtils::declarationForDefinition( DUChainUtils::itemUnderCursor(view->document()->url(), position) );
+        foundDeclaration = DUChainUtils::declarationForDefinition( DUChainUtils::itemUnderCursor(view->document()->url(), position).declaration );
         if (foundDeclaration && foundDeclaration->kind() == Declaration::Alias) {
           AliasDeclaration* alias = dynamic_cast<AliasDeclaration*>(foundDeclaration);
           Q_ASSERT(alias);
@@ -720,10 +832,11 @@ void ContextBrowserPlugin::declarationSelectedInUI(const DeclarationPointer& dec
     m_updateTimer->start(highlightingTimeout); // triggers updateViews()
 }
 
-void ContextBrowserPlugin::parseJobFinished(KDevelop::ParseJob* job)
+void ContextBrowserPlugin::updateReady(const IndexedString& file, const ReferencedTopDUContext& /*topContext*/)
 {
+  const auto url = file.toUrl();
   for(QMap< View*, ViewHighlights >::iterator it = m_highlightedRanges.begin(); it != m_highlightedRanges.end(); ++it) {
-    if(it.key()->document()->url() == job->document().toUrl()) {
+    if(it.key()->document()->url() == url) {
 
       if(!m_updateViews.contains(it.key())) {
         qCDebug(PLUGIN_CONTEXTBROWSER) << "adding view for update";
@@ -810,7 +923,7 @@ void ContextBrowserPlugin::viewCreated( KTextEditor::Document* , View* v )
       return;
 
   iface->setTextHintDelay(highlightingTimeout);
-  iface->registerTextHintProvider(new ContextBrowserHintProvider(this));
+  iface->registerTextHintProvider(&m_textHintProvider);
 }
 
 void ContextBrowserPlugin::registerToolView(ContextBrowserView* view)
@@ -854,7 +967,7 @@ void ContextBrowserPlugin::switchUse(bool forward)
       }
 
       if(!decl) //Try finding a declaration under the cursor
-        decl = DUChainUtils::itemUnderCursor(doc->url(), cCurrent);
+        decl = DUChainUtils::itemUnderCursor(doc->url(), cCurrent).declaration;
 
       if (decl && decl->kind() == Declaration::Alias) {
         AliasDeclaration* alias = dynamic_cast<AliasDeclaration*>(decl);
@@ -873,16 +986,16 @@ void ContextBrowserPlugin::switchUse(bool forward)
           //Try jumping from declaration to definition
           target = FunctionDefinition::definition(decl);
 
-          if(target && target != decl) {
-            KTextEditor::Cursor jumpTo = target->rangeInCurrentRevision().start();
-            QUrl document = target->url().toUrl();
-            lock.unlock();
-            core()->documentController()->openDocument( document, cursorToRange(jumpTo)  );
-            return;
-          }else{
-            //Always work with the declaration instead of the definition
-            decl = DUChainUtils::declarationForDefinition(decl, chosen);
-          }
+        if(target && target != decl) {
+          KTextEditor::Cursor jumpTo = target->rangeInCurrentRevision().start();
+          QUrl document = target->url().toUrl();
+          lock.unlock();
+          core()->documentController()->openDocument( document, cursorToRange(jumpTo)  );
+          return;
+        }else{
+          //Always work with the declaration instead of the definition
+          decl = DUChainUtils::declarationForDefinition(decl, chosen);
+        }
       }
 
       if(!decl) {
@@ -1207,10 +1320,6 @@ void ContextBrowserPlugin::updateHistory(KDevelop::DUContext* context, const KTe
     }
 }
 
-void ContextBrowserPlugin::setAllowBrowsing(bool allow) {
-    m_browseButton->setChecked(allow);
-}
-
 void ContextBrowserPlugin::updateDeclarationListBox(DUContext* context) {
     if(!context || !context->owner()) {
         qCDebug(PLUGIN_CONTEXTBROWSER) << "not updating box";
