@@ -35,6 +35,7 @@
 #include <language/duchain/duchainpointer.h>
 #include <language/duchain/declaration.h>
 #include <language/duchain/indexedducontext.h>
+#include <language/duchain/problem.h>
 #include <language/editor/persistentmovingrange.h>
 #include <language/interfaces/iquickopen.h>
 #include <language/editor/documentcursor.h>
@@ -51,9 +52,9 @@ namespace Sublime {
 
 namespace KDevelop {
   class IDocument;
-  class ParseJob;
   class DUContext;
   class TopDUContext;
+  class ReferencedTopDUContext;
   class DUChainBase;
   class AbstractNavigationWidget;
 }
@@ -65,8 +66,19 @@ namespace KTextEditor {
 
 class ContextBrowserViewFactory;
 class ContextBrowserView;
+class ContextBrowserPlugin;
 class BrowseManager;
 
+class ContextBrowserHintProvider : public KTextEditor::TextHintProvider
+{
+public:
+  explicit ContextBrowserHintProvider(ContextBrowserPlugin* plugin);
+  QString textHint(KTextEditor::View* view, const KTextEditor::Cursor& position) override;
+
+private:
+  ContextBrowserPlugin* m_plugin;
+};
+
 QWidget* masterWidget(QWidget* w);
 
 struct ViewHighlights
@@ -104,7 +116,6 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
                        bool force = false);
 
     void updateDeclarationListBox(KDevelop::DUContext* context);
-    void setAllowBrowsing(bool allow);
 
     void showUses(const KDevelop::DeclarationPointer& declaration) override;
 
@@ -115,13 +126,14 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     
     void startDelayedBrowsing(KTextEditor::View* view);
     void stopDelayedBrowsing();
+    void invokeAction(int index);
     
     void previousUseShortcut();
     void nextUseShortcut();
 
     void declarationSelectedInUI(const KDevelop::DeclarationPointer& decl);
 
-    void parseJobFinished(KDevelop::ParseJob* job);
+    void updateReady(const KDevelop::IndexedString& url, const KDevelop::ReferencedTopDUContext& topContext);
     void textDocumentCreated( KDevelop::IDocument* document );
     void documentActivated( KDevelop::IDocument* );
     void viewDestroyed( QObject* obj );
@@ -160,6 +172,7 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     QWidget* toolbarWidgetForMainWindow(Sublime::MainWindow* window);
     void createActionsForMainWindow(Sublime::MainWindow* window, QString& xmlFile,
                                             KActionCollection& actions) override;
+    QWidget* navigationWidgetForPosition(KTextEditor::View* view, KTextEditor::Cursor position);
     void switchUse(bool forward);
     void clearMouseHover();
 
@@ -214,6 +227,7 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     QPointer<QWidget> m_currentToolTip;
     QPointer<QWidget> m_currentNavigationWidget;
     KDevelop::IndexedDeclaration m_currentToolTipDeclaration;
+    KDevelop::Problem::Ptr m_currentToolTipProblem;
     QAction* m_findUses;
     
     QPointer<KTextEditor::Document> m_lastInsertionDocument;
@@ -245,7 +259,6 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     QPointer<QToolButton> m_previousButton;
     QPointer<QToolButton> m_nextButton;
     QPointer<QMenu> m_previousMenu, m_nextMenu;
-    QPointer<QToolButton> m_browseButton;
     QList<KDevelop::IndexedDeclaration> m_listDeclarations;
     KDevelop::IndexedString m_listUrl;
     BrowseManager* m_browseManager;
@@ -254,16 +267,7 @@ class ContextBrowserPlugin : public KDevelop::IPlugin, public KDevelop::IContext
     int m_nextHistoryIndex;
 
     friend class ContextBrowserHintProvider;
-};
-
-class ContextBrowserHintProvider : public KTextEditor::TextHintProvider
-{
-public:
-  explicit ContextBrowserHintProvider(ContextBrowserPlugin* plugin);
-  QString textHint(KTextEditor::View* view, const KTextEditor::Cursor& position) override;
-
-private:
-  ContextBrowserPlugin* m_plugin;
+    ContextBrowserHintProvider m_textHintProvider;
 };
 
 #endif // KDEVPLATFORM_PLUGIN_CONTEXTBROWSERPLUGIN_H
