@@ -27,14 +27,14 @@ class SessionsModel : public QAbstractListModel
     Q_OBJECT
     public:
         enum Roles { Uuid = Qt::UserRole+1, Projects, ProjectNames, VisibleIdentifier };
-        explicit SessionsModel(QObject* parent = 0);
+        explicit SessionsModel(QObject* parent = nullptr);
         QVariant data(const QModelIndex& index, int role = Qt::DisplayRole) const override;
         int rowCount(const QModelIndex& parent = QModelIndex()) const override;
         QHash< int, QByteArray > roleNames() const override;
 
         Q_SCRIPTABLE void loadSession(const QString& nameOrId) const;
     private:
-        QList<KDevelop::SessionInfo> m_sessions;
+        KDevelop::SessionInfos m_sessions;
 
     private slots:
         void sessionDeleted(const QString& id);
