@@ -494,7 +494,7 @@ void ProjectBaseItem::setFlags(Qt::ItemFlags flags)
 
 QString ProjectBaseItem::iconName() const
 {
-    return QLatin1String("");
+    return QString();
 }
 
 ProjectFolderItem *ProjectBaseItem::folder() const
@@ -1108,30 +1108,7 @@ void ProjectVisitor::visit ( IProject* prj )
 
 void ProjectVisitor::visit ( ProjectBuildFolderItem* folder )
 {
-    foreach( ProjectFileItem* item, folder->fileList() )
-    {
-        visit( item );
-    }
-    foreach( ProjectTargetItem* item, folder->targetList() )
-    {
-        if( item->type() == ProjectBaseItem::LibraryTarget )
-        {
-            visit( dynamic_cast<ProjectLibraryTargetItem*>( item ) );
-        } else if( item->type() == ProjectBaseItem::ExecutableTarget )
-        {
-            visit( dynamic_cast<ProjectExecutableTargetItem*>( item ) );
-        }
-    }
-    foreach( ProjectFolderItem* item, folder->folderList() )
-    {
-        if( item->type() == ProjectBaseItem::BuildFolder )
-        {
-            visit( dynamic_cast<ProjectBuildFolderItem*>( item ) );
-        } else if( item->type() == ProjectBaseItem::Folder )
-        {
-            visit( dynamic_cast<ProjectFolderItem*>( item ) );
-        }
-    }
+    visit(static_cast<ProjectFolderItem*>(folder));
 }
 
 void ProjectVisitor::visit ( ProjectExecutableTargetItem* exec )
@@ -1170,7 +1147,6 @@ void ProjectVisitor::visit ( ProjectFolderItem* folder )
     }
 }
 
-
 void ProjectVisitor::visit ( ProjectFileItem* )
 {
 }
