@@ -272,11 +272,18 @@ PluginController::PluginController(Core *core)
     d->plugins = newPlugins;
 
     KTextEditorIntegration::initialize();
-    const QVector<KPluginMetaData> katePlugins = KPluginLoader::findPlugins(QStringLiteral("ktexteditor"), [](const KPluginMetaData & md) {
+    const QVector<KPluginMetaData> ktePlugins = KPluginLoader::findPlugins(QStringLiteral("ktexteditor"), [](const KPluginMetaData & md) {
         return md.serviceTypes().contains(QStringLiteral("KTextEditor/Plugin"))
             && md.serviceTypes().contains(QStringLiteral("KDevelop/Plugin"));
     });
-    foreach (const auto& info, katePlugins) {
+
+    foundPlugins.clear();
+    std::for_each(ktePlugins.cbegin(), ktePlugins.cend(), [&foundPlugins](const KPluginMetaData& data) {
+        foundPlugins << data.pluginId();
+    });
+    qCDebug(SHELL) << "Found" << ktePlugins.size() << " KTextEditor plugins:" << foundPlugins;
+
+    foreach (const auto& info, ktePlugins) {
         auto data = info.rawData();
         // add some KDevelop specific JSON data
         data[KEY_Category()] = KEY_Global();
@@ -336,6 +343,9 @@ bool PluginController::isEnabled( const KPluginMetaData& info ) const
 
 void PluginController::initialize()
 {
+    QElapsedTimer timer;
+    timer.start();
+
     QMap<QString, bool> pluginMap;
     if( ShellExtension::getInstance()->defaultPlugins().isEmpty() )
     {
@@ -393,6 +403,8 @@ void PluginController::initialize()
     }
     // Synchronize so we're writing out to the file.
     grp.sync();
+
+    qCDebug(SHELL) << "Done loading plugins - took:" << timer.elapsed() << "ms";
 }
 
 QList<IPlugin *> PluginController::loadedPlugins() const
@@ -527,7 +539,7 @@ IPlugin *PluginController::loadPluginInternal( const QString &pluginId )
     auto plugin = factory->create<IPlugin>(d->core);
     if (!plugin) {
         if (auto katePlugin = factory->create<KTextEditor::Plugin>(d->core, QVariantList() << info.pluginId())) {
-            plugin = new KTextEditorIntegration::Plugin(katePlugin, this);
+            plugin = new KTextEditorIntegration::Plugin(katePlugin, d->core);
         } else {
             qWarning() << "Creating plugin" << pluginId << "failed.";
             return nullptr;
@@ -632,8 +644,9 @@ QList<IPlugin*> PluginController::allPluginsForExtension(const QString &extensio
         if( !plugin) {
             plugin = loadPluginInternal( info.pluginId() );
         }
-        if (plugin)
+        if (plugin && !plugins.contains(plugin)) {
             plugins << plugin;
+        }
         return true;
     }, extension, constraints);
     return plugins;
