@@ -48,6 +48,8 @@ QIcon iconForSeverity(KDevelop::IProblem::Severity severity)
         return QIcon::fromTheme(QStringLiteral("dialog-warning"));
     case KDevelop::IProblem::Error:
         return QIcon::fromTheme(QStringLiteral("dialog-error"));
+    case KDevelop::IProblem::NoSeverity:
+        return {};
     }
     return {};
 }
@@ -82,6 +84,7 @@ ProblemModel::ProblemModel(QObject * parent, ProblemStore *store)
     setScope(CurrentDocument);
 
     connect(ICore::self()->documentController(), &IDocumentController::documentActivated, this, &ProblemModel::setCurrentDocument);
+    connect(ICore::self()->documentController(), &IDocumentController::documentClosed, this, &ProblemModel::closedDocument);
     /// CompletionSettings include a list of todo markers we care for, so need to update
     connect(ICore::self()->languageController()->completionSettings(), &ICompletionSettings::settingsChanged, this, &ProblemModel::forceFullUpdate);
 
@@ -283,6 +286,14 @@ void ProblemModel::setCurrentDocument(IDocument* document)
     d->m_problems->setCurrentDocument(IndexedString(currentDocument));
 }
 
+void ProblemModel::closedDocument(IDocument* document)
+{
+    if (IndexedString(document->url()) == d->m_problems->currentDocument())
+    {   // reset current document
+        d->m_problems->setCurrentDocument(IndexedString());
+    }
+}
+
 void ProblemModel::onBeginRebuild()
 {
     beginResetModel();
@@ -303,10 +314,25 @@ void ProblemModel::setScope(int scope)
 
 void ProblemModel::setSeverity(int severity)
 {
-    Q_ASSERT(thread() == QThread::currentThread());
+    switch (severity)
+    {
+        case KDevelop::IProblem::Error:
+            setSeverities(KDevelop::IProblem::Error);
+            break;
+        case KDevelop::IProblem::Warning:
+            setSeverities(KDevelop::IProblem::Error | KDevelop::IProblem::Warning);
+            break;
+        case KDevelop::IProblem::Hint:
+            setSeverities(KDevelop::IProblem::Error | KDevelop::IProblem::Warning | KDevelop::IProblem::Hint);
+            break;
+    }
+}
 
+void ProblemModel::setSeverities(KDevelop::IProblem::Severities severities)
+{
+    Q_ASSERT(thread() == QThread::currentThread());
     /// Will trigger signals beginRebuild(), endRebuild() if problems change and are rebuilt
-    d->m_problems->setSeverity(severity);
+    d->m_problems->setSeverities(severities);
 }
 
 void ProblemModel::setGrouping(int grouping)
