@@ -102,7 +102,6 @@ public:
     QPointer<QAction> m_openConfig;
     IProjectDialogProvider* dialog;
     QList<QUrl> m_currentlyOpening; // project-file urls that are being opened
-    IProject* m_configuringProject;
     ProjectController* q;
     ProjectBuildSetModel* buildset;
     bool m_foundProjectFile; //Temporary flag used while searching the hierarchy for a project file
@@ -111,7 +110,7 @@ public:
     QHash< IProject*, QPointer<KJob> > m_parseJobs; // parse jobs that add files from the project to the background parser.
 
     ProjectControllerPrivate( ProjectController* p )
-        : m_core(0), model(0), selectionModel(0), dialog(0), m_configuringProject(0), q(p), buildset(0), m_foundProjectFile(false), m_cleaningUp(false)
+        : m_core(0), model(0), selectionModel(0), dialog(0), q(p), buildset(0), m_foundProjectFile(false), m_cleaningUp(false)
     {
     }
 
@@ -144,19 +143,20 @@ public:
             }
         }
 
-        Q_ASSERT(!m_configuringProject);
-        m_configuringProject = proj;
-        KDevelop::ConfigDialog cfgDlg(configPages, mainWindow);
-        QObject::connect(&cfgDlg, &ConfigDialog::configSaved, &cfgDlg, [this](ConfigPage* page) {
+        auto cfgDlg = new KDevelop::ConfigDialog(configPages, mainWindow);
+        cfgDlg->setAttribute(Qt::WA_DeleteOnClose);
+        cfgDlg->setModal(true);
+        QObject::connect(cfgDlg, &ConfigDialog::configSaved, cfgDlg, [this, proj](ConfigPage* page) {
             Q_UNUSED(page)
-            Q_ASSERT_X(m_configuringProject, Q_FUNC_INFO,
+            Q_ASSERT_X(proj, Q_FUNC_INFO,
                     "ConfigDialog signalled project config change, but no project set for configuring!");
-            emit q->projectConfigurationChanged(m_configuringProject);
+            emit q->projectConfigurationChanged(proj);
         });
-        cfgDlg.setWindowTitle(i18n("Configure Project %1", proj->name()));
-        cfgDlg.exec();
-        proj->projectConfiguration()->sync();
-        m_configuringProject = nullptr;
+        cfgDlg->setWindowTitle(i18n("Configure Project %1", proj->name()));
+        QObject::connect(cfgDlg, &KDevelop::ConfigDialog::finished, [this, proj]() {
+            proj->projectConfiguration()->sync();
+        });
+        cfgDlg->show();
 
     }
 
@@ -328,7 +328,7 @@ ProjectDialogProvider::ProjectDialogProvider(ProjectControllerPrivate* const p)
 ProjectDialogProvider::~ProjectDialogProvider()
 {}
 
-bool writeNewProjectFile( const QString& localConfigFile, const QString& name, const QString& manager )
+bool writeNewProjectFile( const QString& localConfigFile, const QString& name, const QString& createdFrom, const QString& manager )
 {
     KSharedConfigPtr cfg = KSharedConfig::openConfig( localConfigFile, KConfig::SimpleConfig );
     if (!cfg->isConfigWritable(true)) {
@@ -337,19 +337,20 @@ bool writeNewProjectFile( const QString& localConfigFile, const QString& name, c
     }
     KConfigGroup grp = cfg->group( "Project" );
     grp.writeEntry( "Name", name );
+    grp.writeEntry( "CreatedFrom", createdFrom );
     grp.writeEntry( "Manager", manager );
     cfg->sync();
     return true;
 }
 
-bool writeProjectSettingsToConfigFile(const QUrl& projectFileUrl, const QString& projectName, const QString& projectManager)
+bool writeProjectSettingsToConfigFile(const QUrl& projectFileUrl, OpenProjectDialog* dlg)
 {
     if ( !projectFileUrl.isLocalFile() ) {
         QTemporaryFile tmp;
         if ( !tmp.open() ) {
             return false;
         }
-        if ( !writeNewProjectFile( tmp.fileName(), projectName, projectManager ) ) {
+        if ( !writeNewProjectFile( tmp.fileName(), dlg->projectName(), dlg->selectedUrl().fileName(), dlg->projectManager() ) ) {
             return false;
         }
         // explicitly close file before uploading it, see also: https://bugs.kde.org/show_bug.cgi?id=254519
@@ -359,7 +360,9 @@ bool writeProjectSettingsToConfigFile(const QUrl& projectFileUrl, const QString&
         KJobWidgets::setWindow(uploadJob, Core::self()->uiControllerInternal()->defaultMainWindow());
         return uploadJob->exec();
     }
-    return writeNewProjectFile( projectFileUrl.toLocalFile(),projectName, projectManager );
+    // Here and above we take .filename() part of the selectedUrl() to make it relative to the project root,
+    // thus keeping .kdev file relocatable
+    return writeNewProjectFile( projectFileUrl.toLocalFile(), dlg->projectName(), dlg->selectedUrl().fileName(), dlg->projectManager() );
 }
 
 
@@ -394,6 +397,9 @@ QUrl ProjectDialogProvider::askProjectConfigLocation(bool fetch, const QUrl& sta
 
     QUrl projectFileUrl = dlg.projectFileUrl();
     qCDebug(SHELL) << "selected project:" << projectFileUrl << dlg.projectName() << dlg.projectManager();
+    if ( dlg.projectManager() == "<built-in>" ) {
+        return projectFileUrl;
+    }
 
     // controls if existing project file should be saved
     bool writeProjectConfigToFile = true;
@@ -401,18 +407,21 @@ QUrl ProjectDialogProvider::askProjectConfigLocation(bool fetch, const QUrl& sta
     {
         // check whether config is equal
         bool shouldAsk = true;
-        if( projectFileUrl.isLocalFile() )
+        if( projectFileUrl == dlg.selectedUrl() )
         {
-            shouldAsk = !equalProjectFile( projectFileUrl.toLocalFile(), &dlg );
-        } else {
-            shouldAsk = false;
+            if( projectFileUrl.isLocalFile() )
+            {
+                shouldAsk = !equalProjectFile( projectFileUrl.toLocalFile(), &dlg );
+            } else {
+                shouldAsk = false;
 
-            QTemporaryFile tmpFile;
-            if (tmpFile.open()) {
-                auto downloadJob = KIO::file_copy(projectFileUrl, QUrl::fromLocalFile(tmpFile.fileName()));
-                KJobWidgets::setWindow(downloadJob, qApp->activeWindow());
-                if (downloadJob->exec()) {
-                    shouldAsk = !equalProjectFile(tmpFile.fileName(), &dlg);
+                QTemporaryFile tmpFile;
+                if (tmpFile.open()) {
+                    auto downloadJob = KIO::file_copy(projectFileUrl, QUrl::fromLocalFile(tmpFile.fileName()));
+                    KJobWidgets::setWindow(downloadJob, qApp->activeWindow());
+                    if (downloadJob->exec()) {
+                        shouldAsk = !equalProjectFile(tmpFile.fileName(), &dlg);
+                    }
                 }
             }
         }
@@ -446,7 +455,7 @@ QUrl ProjectDialogProvider::askProjectConfigLocation(bool fetch, const QUrl& sta
     }
 
     if (writeProjectConfigToFile) {
-        if (!writeProjectSettingsToConfigFile(projectFileUrl, dlg.projectName(), dlg.projectManager())) {
+        if (!writeProjectSettingsToConfigFile(projectFileUrl, &dlg)) {
             KMessageBox::error(d->m_core->uiControllerInternal()->defaultMainWindow(),
                 i18n("Unable to create configuration file %1", projectFileUrl.url()));
             return QUrl();
@@ -686,7 +695,6 @@ void ProjectController::openProjectForUrl(const QUrl& sourceUrl) {
     d->m_foundProjectFile = false;
 
     while(!testAt.path().isEmpty()) {
-        QUrl testProjectFile(testAt);
         KIO::ListJob* job = KIO::listDir(testAt);
 
         connect(job, &KIO::ListJob::entries, this, &ProjectController::eventuallyOpenProjectFile);
@@ -1125,12 +1133,12 @@ QString ProjectController::mapSourceBuild( const QString& path_, bool reverse, b
     IProject* sourceDirProject = 0, *buildDirProject = 0;
     Q_FOREACH(IProject* proj, d->m_projects)
     {
-        if(proj->path().isParentOf(path))
+        if(proj->path().isParentOf(path) || proj->path() == path)
             sourceDirProject = proj;
         if(proj->buildSystemManager())
         {
             Path buildDir = proj->buildSystemManager()->buildDirectory(proj->projectItem());
-            if(buildDir.isValid() && buildDir.isParentOf(path))
+            if(buildDir.isValid() && (buildDir.isParentOf(path) || buildDir == path))
                 buildDirProject = proj;
         }
     }
