@@ -42,6 +42,7 @@ class MainWindow;
 class Core;
 
 class WorkingSet;
+class WorkingSetToolTipWidget;
 
 class WorkingSetController : public QObject
 {
@@ -68,7 +69,7 @@ public:
     QList<WorkingSet*> allWorkingSets() const;
 
     //The returned widget is owned by the caller
-    QWidget* createSetManagerWidget(MainWindow* parent, Sublime::Area* fixedArea = 0);
+    QWidget* createSetManagerWidget(MainWindow* parent, Sublime::Area* fixedArea = nullptr);
 
     void initializeController(UiController* controller);
 
@@ -107,6 +108,7 @@ private slots:
     void clearWorkingSet(Sublime::Area* area);
 
 private:
+    WorkingSetToolTipWidget* workingSetToolTip();
     void setupActions();
     const QString makeSetId(const QString& prefix) const;
 
