@@ -23,7 +23,6 @@
 #include <QClipboard>
 #include <QEvent>
 #include <QLabel>
-#include <QMap>
 #include <QMenu>
 #include <QMouseEvent>
 #include <QPointer>
@@ -121,7 +120,7 @@ bool sortViews(const View* const lhs, const View* const rhs)
 
 struct ContainerPrivate {
     QBoxLayout* layout;
-    QMap<QWidget*, View*> viewForWidget;
+    QHash<QWidget*, View*> viewForWidget;
 
     ContainerTabBar *tabBar;
     QStackedWidget *stack;
@@ -131,7 +130,7 @@ struct ContainerPrivate {
     QPointer<QWidget> leftCornerWidget;
     QToolButton* documentListButton;
     QMenu* documentListMenu;
-    QMap<View*, QAction*> documentListActionForView;
+    QHash<View*, QAction*> documentListActionForView;
 
     /**
      * Updates the context menu which is shown when
@@ -370,7 +369,7 @@ void Container::statusChanged(Sublime::View* view)
 
 void Container::statusIconChanged(Document* doc)
 {
-    QMapIterator<QWidget*, View*> it = d->viewForWidget;
+    QHashIterator<QWidget*, View*> it = d->viewForWidget;
     while (it.hasNext()) {
         if (it.next().value()->document() == doc) {
             d->fileStatus->setPixmap( doc->statusIcon().pixmap( QSize( 16,16 ) ) );
@@ -390,12 +389,12 @@ void Container::statusIconChanged(Document* doc)
 
 void Container::documentTitleChanged(Sublime::Document* doc)
 {
-    QMapIterator<QWidget*, View*> it = d->viewForWidget;
+    QHashIterator<QWidget*, View*> it = d->viewForWidget;
     while (it.hasNext()) {
         Sublime::View* view = it.next().value();
         if (view->document() == doc) {
             if (currentView() == view) {
-                d->fileNameCorner->setText( doc->title(Document::Extended) );
+                d->fileNameCorner->setText( doc->title(Document::Extended) + i18n(" <i><small>(Press Ctrl+Tab to switch)</small></i>") );
             }
             int tabIndex = d->stack->indexOf(it.key());
             if (tabIndex != -1) {
@@ -527,6 +526,17 @@ void Container::setTabColor(const View* view, const QColor& color)
     }
 }
 
+void Container::setTabColors(const QHash<const View*, QColor>& colors)
+{
+    for (int i = 0; i < count(); i++) {
+        auto view = viewForWidget(widget(i));
+        auto color = colors[view];
+        if (color.isValid()) {
+            d->tabBar->setTabTextColor(i, color);
+        }
+    }
+}
+
 void Container::tabMoved(int from, int to)
 {
     QWidget *w = d->stack->widget(from);
